<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\V1\Chemicals;

use App\Exceptions\ServerRunTimeException;
use App\Rhawn\Services\Chemsite\ChemsiteCompanyService;
use App\Services\Api\ChemicalsMsdsService;
use App\Services\Api\Chemsite\ChemsiteCustomerService;
use App\Services\CustomerService;
use App\Services\FileService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Http\Controllers\V1\Controller;
use App\Support\Traits\Helpers;

class MsdsController extends Controller
{
    use Helpers;

    public function __construct(ChemicalsMsdsService $chemicalsMsdsService)
    {
       $this->chemicalsMsdsService= $chemicalsMsdsService;
    }

    public function getMsds(Request $request)
    {
        try{
            $companyCode = $request->get('company_code');
            $cusNumber = $request->get('cus_number');

            $params = $this->formatKeysfromArray($request->all(),'toUnderScore');
            $cas = $params['cas'];
            $msdsType = $params['msds_type'];

            if(!$companyCode){
                return Response::ok('验证失败,参数缺少!');
            }
            if(!$cas){
                return Response::ok('验证失败,缺少cas参数!');
            }
            if(!$msdsType){
                return Response::ok('验证失败,缺少msds类型参数!');
            }

            if(!in_array($msdsType, ['cn', 'en'])){
                return Response::ok('验证失败,获取类型错误!');
            }

            $companyInfo = app(ChemsiteCompanyService::class)->getCompanyThroughCusCode($companyCode);
            if(!$companyInfo){
                throw new ServerRunTimeException('经销商不存在');
            }
            if($cusNumber){
                $customer = app(ChemsiteCustomerService::class)->getCustomerByNumber($cusNumber);
                if(!$customer){
                    throw new ServerRunTimeException('客户不存在');
                }
                if($customer['com_id'] != $companyInfo['com_id']){
                    throw new ServerRunTimeException('不是该经销商的客户');
                }
            }

            $platformCompanyInfo = app(CustomerService::class)->getPlatformCustomer(['cus_number' => $companyCode]);
            $pdf = $this->chemicalsMsdsService->getMsds($cas, $msdsType, $platformCompanyInfo);

            return Response::success($this->formatKeysfromArray(['download' => env('DOWNLOAD_URL').$pdf]),'操作成功');
        }catch(\Throwable $exception){
            return $this->returnErrorExecptionResponse($exception,'获取msds失败');
        }
    }

    public function downloadFile($path)
    {
        try{
            ob_end_clean();
            return app(FileService::class)->download($path);
        }catch(\Throwable $exception){
            $this->returnErrorExecptionResponse($exception);
        }
    }

    public function viewPdf($path)
    {
        try{
            ob_end_clean();

            $file = app(FileService::class)->loadFile($path);
            header('content-type: application/pdf');
            echo $file;

        }catch(\Throwable $exception){
            dd($exception->getMessage());
            $this->returnErrorExecptionResponse($exception);
        }
    }
}
