<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Http\Controllers\V1;

use App\Services\CustomerService;
use Illuminate\Auth\AuthenticationException;
use Jiannei\Response\Laravel\Support\Facades\Response;
use Jiannei\Response\Laravel\Support\Traits\ExceptionTrait;
use Laravel\Lumen\Routing\Controller as BaseController;
use OpenApi\Annotations\Info;
use OpenApi\Annotations\Schema;
use OpenApi\Annotations\Server;
use OpenApi\Annotations\Property;
use OpenApi\Annotations\SecurityScheme;


/**
 *
 * @Info(
 *     version="1.0",
 *     title="罗恩开放平台 API接口文档"
 * )
 *
 * @Schema(
 *     schema="ApiResponse",
 *     type="object",
 *     title="接口返回统一响应实体",
 *     @Property(property="status", type="string", description="响应结果提示"),
 *     @Property(
 *         property="code",
 *         type="string",
 *         description="响应代码"
 *     ),
 *     @Property(property="message", type="string", description="响应结果提示"),
 *     @Property(property="data", type="object", description="响应结果数据集"),
 *     @Property(property="error", type="object", description="响应错误结果数据集")
 * )
 *
 */

abstract class Controller extends BaseController
{
    use ExceptionTrait;


    /**
     * request 参数验证
     * @param $request
     * @param $message
     * @return bool|\Illuminate\Http\JsonResponse
     */
    protected function validateRequest($request, $message){

        $validateArr = [];
        collect($message)->map(function($value,$key) use (&$validateArr){
            $keys = explode('.',$key);
            $validateArr[$keys[0]] = $keys[1];
        });

        $validator = Validator($request->all(), $validateArr, $message);

        if ($validator->fails()) {
            foreach($validator->errors()->getMessages() as $error) {
                return Response::fail($error[0]);
            }
        }
        return true;
    }

    protected function returnErrorExecptionResponse(\Exception $exception, string $message = '')
    {
        if($exception->getCode() == 500 || $exception->getCode() == 502){
            return Response::fail($exception->getMessage(),200);
        }
        return Response::fail($message == '' ? $exception->getMessage() : $message,200);
    }

    protected function checkCustomerType($customerCode,$type)
    {
        $customer = app(CustomerService::class)->getPlatformCustomer(['cus_number' => $customerCode, 'cus_type' => $type]);
        if($customer){
            if($customer['cus_type'] != $type){
                switch($type){
                    case 'bh' : $this->returnErrorExecptionResponse(new AuthenticationException('不是百化用户，无法访问该类型接口'));break;
                    case 'rhawn' : $this->returnErrorExecptionResponse(new AuthenticationException('不是罗恩用户，无法访问该类型接口'));break;
                    case 'chemsite' : $this->returnErrorExecptionResponse(new AuthenticationException('不是chemsite用户，无法访问该类型接口'));break;
                    default : $this->returnErrorExecptionResponse(new AuthenticationException('用户类型未知'));
                }
            }
        }
    }
}
