<?php

namespace App\Http\Controllers\V1;

use App\Services\CustomerService;
use Illuminate\Http\Request;
use Jiannei\Response\Laravel\Support\Facades\Response;
use App\Http\Controllers\V1\Controller;
use App\Support\Traits\Helpers;

class CustomersController extends Controller
{
    use Helpers;

    public function __construct(CustomerService $customerService)
    {
        $this->customerService = $customerService;
    }

    public function createCustomer(Request $request)
    {
        $message = [
            'customerCode.required' => "客户编号必传",
            'customerType.required' => "客户类型必传",
            'customerCompany.required' => "客户公司必传",
        ];
        $this->validateRequest($request, $message);

        $requestParams = $this->formatKeysfromArray($request->all(),'toUnderScore');
        try{
            if($requestParams['customer_type'] == 'chemsite'){
                $requestParams['platform_params']['company_name'] = $requestParams['company_name'] ?? '';
                $requestParams['platform_params']['company_address'] = $requestParams['company_adress'] ?? '';
                $requestParams['platform_params']['company_fax'] = $requestParams['company_fax'] ?? '';
                $requestParams['platform_params']['company_phone'] = $requestParams['company_phone'] ?? '';
            }
            $customer = $this->customerService->createPlatformCustomer($requestParams);
            return Response::success($customer,'操作成功');
        }catch(\Throwable $exception){
            return $this->returnErrorExecptionResponse($exception,'客户创建失败');
        }
    }

    /**
     * 搜索客户信息
     * @param Request $request
     * @return \Illuminate\Http\JsonResponse|\Illuminate\Http\Resources\Json\JsonResource
     */
    public function searchCustomersList(Request $request)
    {
        $requestParams = $this->formatKeysfromArray($request->all(),'toUnderScore');
        try{
            switch($requestParams['customer_type']){
                case 'openapi' :
                    $customer = $this->customerService->getList($requestParams);
                    break;
                case 'bh' :
                case 'rhawn' :
                    $customer = $this->customerService->searchOtherCustomerInfo($requestParams);
                    break;
            }
            return Response::success($this->formatKeysfromArray($customer),'操作成功');
        }catch(\Throwable $exception){
            return $this->returnErrorExecptionResponse($exception,'客户获取失败');
        }
    }

}
