<?php
namespace App\Mailer;

use App\Providers\MailerServiceProvider;
use Illuminate\Contracts\Mail\Mailer;
use Illuminate\Mail\MailServiceProvider;
use Illuminate\Support\Facades\Mail;

class MailService{

    private $type;

    public function __construct(Mailer $mailer)
    {
        $this->mailer = $mailer;
        $this->registerProvider($this->getMailAccountConfig());
    }

    public function setFromType($type)
    {
        $this->type = strtoupper($type);
        return $this;
    }

    public function initSendService()
    {
        if(!$this->type){
            throw new \Exception('send type not exist.');
        }

        $this->registerProvider($this->getMailAccountConfig($this->type));
    }

    public function getMailAccountConfig($emailSmtp = 'rhawn')
    {
        $config = config('mail');
        $config['mailers']['smtp']['host'] = env(strtoupper($emailSmtp)."_MAIL_HOST");
        $config['mailers']['smtp']['port'] = env(strtoupper($emailSmtp)."_MAIL_PORT");
        $config['mailers']['smtp']['encryption'] = env(strtoupper($emailSmtp)."_MAIL_ENCRYPTION");
        $config['mailers']['smtp']['username'] = env(strtoupper($emailSmtp)."_MAIL_USERNAME");
        $config['mailers']['smtp']['password'] = env(strtoupper($emailSmtp)."_MAIL_PASSWORD");
        $config['from']['address'] = env(strtoupper($emailSmtp)."_MAIL_FROM_ADDRESS");
        $config['from']['name'] = env(strtoupper($emailSmtp)."_MAIL_FROM_NAME");

        return $config;
    }

    public function registerProvider($config)
    {
        app('config')->set(['mail' => $config]);
        //$mailerServiceProvider = app(MailerServiceProvider::class);
        //$mailerServiceProvider->setMailerPlatform('rhawn');
        app()->register(MailServiceProvider::class);
    }

    public function sendMail($title, $toUser, $message)
    {
        $this->setFromType('zkh')->initSendService();
        Mail::raw($message,function($mail) use ($toUser, $title){
           $mail->to($toUser);
           $mail->subject($title);

        });
    }

    public function sendMailToHtml($type, $title, $toUser, $html)
    {
        $this->setFromType($type)->initSendService();
        return Mail::mailer('smtp_'.$type)->html($html,function($mail) use ($toUser, $title){
            $mail->to($toUser);
            $mail->subject($title);

        });
    }
}