<?php

namespace App\Rhawn\Repositories\Eloquent\Chemsite;

use App\Rhawn\Repositories\Contracts\Chemsite\ChemsiteProductRepository;
use App\Rhawn\Repositories\Eloquent\BaseRepository;
use App\Rhawn\Repositories\Models\BhuaProducts;
use App\Rhawn\Repositories\Models\Chemsite\ChemsiteProducts;
use Illuminate\Support\Facades\DB;

class ChemsiteProductRepositoryEloquent extends BaseRepository implements ChemsiteProductRepository
{
    /**
     * Specify Model class name.
     *
     * @return string
     */
    public function model()
    {
        return ChemsiteProducts::class;
    }

    /**
     * 根据p_code获取产品信息
     * @param $pCode
     * @return null
     */
    public function getProductByPcode($pCode)
    {
        $productsModel = ChemsiteProducts::query();
        if(!is_array($pCode)){
            $productsModel->where('products.p_code','=',$pCode);
        }else{
            $productsModel->whereIn('products.p_code',$pCode);
        }
        $product = $productsModel->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }

    public function getProductByPcodeAndBid($pCode,$bId)
    {
        $productsModel = ChemsiteProducts::query();
        if(!is_array($pCode)){
            $productsModel->where('products.p_code','=',$pCode);
        }else{
            $productsModel->whereIn('products.p_code',$pCode);
        }
        $productsModel->where('products.b_id',$bId);
        //$productsModel->where('products.com_id',$comId);
        $product = $productsModel->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }

    public function getProductsByWhere(array $where)
    {
        $productsModel = ChemsiteProducts::query();
        foreach($where as $key => $w){
            if(!is_array($w)){
                $productsModel->where($key,$w);
            }else{
                $productsModel->whereIn($key,$w);
            }
        }
        $product = $productsModel->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }

    /**
     * 根据pid获取产品对应的促销信息
     * @param $pId
     * @return array|null
     */
    public function getProductPromotionByPid($pId)
    {
        $promotionsModel = DB::connection($this->getConnectionName())
            ->table('promotions_products')
            ->join('promotions','promotions.pt_id','promotions_products.pt_id');
        if(is_array($pId)){
            $promotionsModel->whereIn('promotions_products.p_id',$pId);
        }else{
            $promotionsModel->where('promotions_products.p_id',$pId);
        }
        /*$promotions = $promotionsModel->where('promotions.pt_start','<=',time())
            ->where('promotions.pt_end','>=',time())
            ->get();*/
        $promotions = $promotionsModel->get();
        if($promotions){
            $promotions = $promotions->toArray();
            return $promotions;
        }
        return null;
    }

    /**
     * 获取所有产品的包装规格
     * @return array
     */
    public function getProductPackagesThroughGroupByPackUnit()
    {
        $packages = ChemsiteProducts::query()
            ->select('p_pack','p_pack_unit')
            ->groupBy('p_pack','p_pack_unit')
            ->get();

        return $packages->toArray();
    }

    /**
     * 获取产品信息
     * @param $where
     * @param $offset
     * @param $pageSize
     * @return null
     */
    public function getProductsList($where, $offset, $limit)
    {
        $productsModel = ChemsiteProducts::query();
        if(!empty($where)){
            foreach($where as $key => $w){
                if(!is_array($w)){
                    $productsModel->where($key,$w);
                }else{
                    $productsModel->whereIn($key,$w);
                }
            }
        }
        $product = $productsModel->offset($offset)->limit($limit)->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }

    public function getProductsByCas($cas)
    {
        $productsModel = ChemsiteProducts::query();
        $product = $productsModel->where('chemicals.c_cas',$cas)->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }

    public function getProductCasByBidToGroupByCas($bId)
    {
        $productsModel = ChemsiteProducts::query()->select('chemicals.c_cas');
        $productsModel = $productsModel->join('chemicals','chemicals.c_id','products.c_id');
        $product = $productsModel->where('products.b_id',$bId)->groupBy('chemicals.c_cas')->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }

    /**
     * @param $brandId
     * @param $offset
     * @param $limit
     * @return null
     */
    public function getProductsListByBrandId($brandId, $offset, $limit)
    {
        $productsModel = $this->join('chemicals', 'chemicals.c_id','products.c_id');
        $product = $productsModel->where('products.b_id',$brandId)
            //->where('p_status',1)
            ->where('p_show',1)
            ->offset($offset)->limit($limit)->get();
        if($product){
            return $product->toArray();
        }
        return null;
    }
}
