<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Rhawn\Services;

use App\Rhawn\Repositories\Contracts\BhuaSordersRepository;
use App\Rhawn\Repositories\Eloquent\BhuaCustomerRepositoryEloquent;
use App\Rhawn\Repositories\Eloquent\BhuaProductRepositoryEloquent;
use App\Rhawn\Repositories\Eloquent\BhuaSoitemsRepositoryEloquent;
use App\Support\Facades\SimpleLogs;
use Illuminate\Support\Facades\DB;

class BhuaOrdersService
{
    public function __construct(BhuaSordersRepository $bhuaSorderRepository)
    {
        $this->bhuaSorderRepository = $bhuaSorderRepository;
    }

    public function getCustomerOrderItems($cusCode, $soItems)
    {
        if(empty($soItems)){
            throw new \Exception('订单项为空',500);
        }

        $customerReopository = app(BhuaCustomerRepositoryEloquent::class);
        $discount = $customerReopository->getCustomerDiscountByCusCode($cusCode);

        $total = 0;
        $weight = 0;
        $productRepository = app(BhuaProductRepositoryEloquent::class);
        foreach($soItems as $k => $v){
            $productInfo = $productRepository->getProductByPcodeAndBid($v['p_code'],$v['brand_id']);
            if(!$productInfo){
                throw new \Exception($v['p_code'].'产品不存在!',500);
            }
            $productInfo = current($productInfo);
            if($productInfo['p_status'] == 0 || $productInfo['p_show'] == 0){
                throw new \Exception($v['p_code'].'产品已下架!',500);
            }

            if(isset($discount[$productInfo['b_id']])){
                $productInfo['p_discount'] = round($discount[$productInfo['b_id']]['cd_discount'] * $productInfo['p_price']);
            }else{
                $productInfo['p_discount'] = $productInfo['p_price'];
            }

            $soItems[$k]['amount'] = round(bcmul($productInfo['p_discount'],$v['num'],3),2);
            $soItems[$k]['weight'] = round(bcmul($productInfo['p_weight'],$v['num'],3),3);
            //得到品牌
            $brands = DB::connection($this->bhuaSorderRepository->getConnectionName())
                ->table('brands')
                ->where('b_id',$productInfo['b_id'])
                ->first();
            if(!$brands){
                throw new \Exception('品牌不存在',500);
            }
            $productInfo['b_cn_name'] = $brands->b_cn_name;

            $soItems[$k]['product_info'] = $productInfo;
            $total += $soItems[$k]['amount'];
            $weight += $soItems[$k]['weight'];
        }

        $returnItems = [];
        $returnItems['total'] = $total;
        $returnItems['weight'] = $weight;
        $returnItems['rows'] = $soItems;

        return $returnItems;
    }

    /**
     * 新增订单
     * @param $data
     * @return false
     */
    public function createOrders($data)
    {
        $connection = DB::connection($this->bhuaSorderRepository->getConnectionName());
        try{
           $connection->beginTransaction();

            $data['sorders']['so_no'] = '';
            $data['sorders']['so_ctime'] = time();
            //$data['sorders']['so_creater'] = $data['sorders']['creater'];

            $orderId = $connection->table('sorders')->insertGetId($data['sorders']);

            $soNo = 1000000 + $orderId;
            $soNo = date('Ymd',time()).'-'.$soNo;

            $connection->table('sorders')
                ->where('so_id',$orderId)
                ->update([
                    'so_no' => $soNo
                ]);

            $soitems = [];
            foreach($data['soitems'] as $k => $v){
                $soitems[$k]['so_id'] = $orderId;
                $soitems[$k]['p_id'] = $v['p_id'];
                $soitems[$k]['si_price'] = $v['si_price'];
                $soitems[$k]['si_discount'] = $v['si_discount'];
                $soitems[$k]['si_num'] = $v['si_num'];
                $soitems[$k]['si_amount'] = $v['si_amount'];
                $soitems[$k]['si_p_tod'] = $v['si_p_tod'];
                $soitems[$k]['si_note'] = '';
            }
            if($data['express'] > 0){
                $soitems_count = count($soitems);
                $soitems[$soitems_count]['so_id'] = $orderId;
                $soitems[$soitems_count]['p_id'] = 0;
                $soitems[$soitems_count]['si_price'] = 0;
                $soitems[$soitems_count]['si_discount'] = 0;
                $soitems[$soitems_count]['si_num'] = 0;
                $soitems[$soitems_count]['si_amount'] = $data['express'];
                $soitems[$soitems_count]['si_p_tod'] = '';
                $soitems[$soitems_count]['si_note'] = '';
            }

            $connection->table('soitems')->insert($soitems);
            $connection->table('logs')->insert(
                [
                    'l_obj'=>$orderId,
                    'l_type'=>'sorders_mng',
                    'l_op'=>'add',
                    'l_op_name'=>'新增',
                    'l_note'=>$data['sorders']['so_note'],
                    'l_timestamp'=>time(),'u_id'=>$data['sorders']['so_creater']
                ]
            );
            $connection->commit();

            return $orderId;

        }catch(\Throwable $exception){
            $connection->rollBack();
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':createOrders','error');
            throw $exception;
        }
    }

    /**
     * 计算运费
     * @param $weight
     * @param $province
     * @param $total
     * @param $if_free_express
     * @param $cus_level
     * @return float|int
     */
    public function getExpress($weight,$province,$total){
        //计算运费 (运费=首重（1kg）*运输系数（首重）+续重（总重量-1kg）*运输系数（续重）)
        $express = 0;
        if($weight == 0){
            $weight = 0.1;
        }
        if($total < 99 && $weight > 0){
            $weight = ceil($weight);
            if($province == '江苏省' || $province == '浙江省' || $province == '上海' || $province == '江苏' || $province == '浙江'){
                $express = ($weight - 1)*2 + 6;
            }else{
                $express = ($weight - 1)*8 + 10;
            }
        }
        return $express;
    }

    public function getCustomerOrderItemsByOrderId($cusId, $orderId)
    {
        return $this->bhuaSorderRepository->getCustomerOrderItemsByOrderId($cusId, $orderId);
    }

    public function getSordersByOrderNo($orderNo)
    {
        $order = $this->bhuaSorderRepository->getSorderFromOrderNo($orderNo);
        if($order){
            return $order->toArray();
        }
        return null;
    }

    /**
     * 获取订单配货单详情
     * @param $orderNumber
     */
    public function getOrderDispatchDetail($orderNumber)
    {
        try{
            $dpdetail = $this->bhuaSorderRepository->getOrderDispatch($orderNumber);
            $soItemIds = [];
            if($dpdetail){
                foreach($dpdetail as $detail){
                    $soItemIds[] = $detail['si_id'];
                }
                $soItems = app(BhuaSoitemsRepositoryEloquent::class)->getSorderItemFromItemId($soItemIds);
                if(!$soItems){
                    throw new \Exception('订单项不存在',500);
                }
                $orderItems = [];
                foreach($soItems as $item){
                    $orderItems[$item['si_id']] = $item;
                }
                foreach($dpdetail as &$detail){
                    if(isset($orderItems[$detail['si_id']]) && !empty($orderItems[$detail['si_id']])){
                        $detail['si_id'] = $orderItems[$detail['si_id']];
                    }
                }
            }
            return $dpdetail;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':getOrderDispatchDetail','error');
            throw $exception;
        }
    }
}
