<?php

/*
 * This file is part of the Jiannei/lumen-api-starter.
 *
 * (c) Jiannei <longjian.huang@foxmail.com>
 *
 * This source file is subject to the MIT license that is bundled
 * with this source code in the file LICENSE.
 */

namespace App\Services\Api\Chemsite;

use App\Repositories\Transformers\Rhawn\OrderDetailTransformer;
use App\Repositories\Transformers\Rhawn\OrdersDispatchTransformer;
use App\Rhawn\Repositories\Eloquent\Chemsite\ChemsiteCompanyRepositoryEloquent;
use App\Support\Facades\SimpleLogs;

class ChemsiteOrdersService
{
    public function __construct(\App\Rhawn\Services\Chemsite\ChemsiteOrdersService $chemsiteOrdersService)
    {
        $this->chemsiteOrdersService = $chemsiteOrdersService;
        $this->chemsiteCustomerService = app(\App\Rhawn\Services\Chemsite\ChemsiteCustomerService::class);
    }

    /**
     * 新增订单
     * @param $requestParams
     */
    public function createNewCustomerOrders($requestParams)
    {
        try {
            $customer = $this->chemsiteCustomerService->checkCustomerExist($requestParams['customer_code']);

            if (!isset($requestParams['so_ca_county'])) {
                $requestParams['so_ca_county'] = '';
            }

            $companyInfo = app(ChemsiteCompanyRepositoryEloquent::class)->getCompanyThroughCusCode($requestParams['company_code']);
            $companyInfo = $companyInfo->toArray();
            if(!$companyInfo){
                throw new \Exception('未找到相应供应商',500);
            }

            $orderItems = $this->chemsiteOrdersService->getCustomerOrderItems($companyInfo['com_id'], $customer['cus_no'], $requestParams['items']);
            if (!$orderItems) {
                throw new \Exception('货号无法匹配', 500);
            }

            /*$express = $this->chemsiteOrdersService->getExpress(
                $orderItems['weight'], $requestParams['so_ca_province'], $orderItems['total']
            );*/
            $express = 0;

            $order = $this->chemsiteOrdersService->chemsiteSordersRepository->getSorderFromOrderCusPo($requestParams['so_cus_po']);
            if ($order) {
                throw new \Exception('不能重复创建新订单!', 500);
            }

            $data = [];
            $data['sorders']['cus_id'] = $customer['cus_id'];
            $data['sorders']['so_cus_po'] = $requestParams['so_cus_po'];
            $data['sorders']['so_ca_name'] = $requestParams['so_ca_name'];
            $data['sorders']['so_ca_mobile'] = $requestParams['so_ca_mobile'];
            $data['sorders']['so_ca_phone'] = !isset($requestParams['so_ca_phone']) ? '' : $requestParams['so_ca_phone'];

            if (!isset($requestParams['so_ca_province']) || empty($requestParams['so_ca_province'])) {
                throw new \Exception('省份必填');
            } else {
                $data['sorders']['so_ca_province'] = $requestParams['so_ca_province'];
            }

            if (!isset($requestParams['so_ca_city']) || empty($requestParams['so_ca_city'])) {
                throw new \Exception('城市必填');
            } else {
                $data['sorders']['so_ca_city'] = $requestParams['so_ca_city'];
            }
            if (!isset($requestParams['so_ca_county']) || empty($requestParams['so_ca_county'])) {
                throw new \Exception('区县必填');
            } else {
                $data['sorders']['so_ca_county'] = $requestParams['so_ca_county'];
            }
            if (!isset($requestParams['so_ca_street']) || empty($requestParams['so_ca_street'])) {
                throw new \Exception('街道必填');
            } else {
                $data['sorders']['so_ca_street'] = $requestParams['so_ca_street'];
            }

            if ($requestParams['so_payment_method'] != 3) {

                //得到收票地址
                $cusiaddrs_arr = $this->chemsiteCustomerService->chemsiteCustomerRepository->getCustomerAddressByCusCode($customer['cus_no']);
                $cusinvoice_arr = $this->chemsiteCustomerService->chemsiteCustomerRepository->getCustomerInvoiceByCusCode($customer['cus_no']);

                if (!$cusiaddrs_arr) {
                    throw new \Exception('请至会员中心设置收票地址', 500);
                }
                if (!$cusinvoice_arr) {
                    throw new \Exception('请至会员中心设置发票信息', 500);
                }

                $cusiaddrs_arr = current($cusiaddrs_arr);
                $cusinvoice_arr = current($cusinvoice_arr);

                $data['sorders']['so_cia_name'] = $cusiaddrs_arr['cia_name'];
                $data['sorders']['so_cia_mobile'] = $cusiaddrs_arr['cia_mobile'];
                $data['sorders']['so_cia_phone'] = $cusiaddrs_arr['cia_phone'];
                $data['sorders']['so_cia_province'] = $cusiaddrs_arr['cia_province'];
                $data['sorders']['so_cia_city'] = $cusiaddrs_arr['cia_city'];
                $data['sorders']['so_cia_county'] = $cusiaddrs_arr['cia_county'];
                $data['sorders']['so_cia_street'] = $cusiaddrs_arr['cia_street'];

                $data['sorders']['so_cia_name'] = $cusiaddrs_arr['cia_name'];
                $data['sorders']['so_ci_type'] = $cusinvoice_arr['ci_type'];
                $data['sorders']['so_ci_title'] = $cusinvoice_arr['ci_title'];
                $data['sorders']['so_ci_vatno'] = $cusinvoice_arr['ci_vatno'];
                $data['sorders']['so_ci_bank'] = $cusinvoice_arr['ci_bank'];
                $data['sorders']['so_ci_bknum'] = $cusinvoice_arr['ci_bknum'];
                $data['sorders']['so_ci_addr'] = $cusinvoice_arr['ci_addr'];
                $data['sorders']['so_ci_phone'] = $cusinvoice_arr['ci_phone'];
            }
            $data['sorders']['so_ci_method'] = $requestParams['so_payment_method'];

            $data['sorders']['so_creater'] = 0;//$customer['cus_id'];

            if(!isset($requestParams['so_note'])){
                $requestParams['so_note'] = '';
            }

            $data['sorders']['so_note'] = $requestParams['so_note'];
            $data['sorders']['so_send_note'] = $customer['cus_send_note'];
            $data['sorders']['so_ci_method'] = 1;
            $data['sorders']['so_total'] = $orderItems['total'] + $express;
            $data['express'] = $express;
            $data['v_id'] = '';
            $data['soitems'] = [];
            foreach($orderItems['rows'] as $k => $v){
                $soitem = [];
                $soitem['p_id'] = $v['product_info']['p_id'];
                $soitem['si_price'] = $v['product_info']['p_price'];
                $soitem['si_discount'] = $v['product_info']['p_discount'];
                $soitem['si_num'] = $v['num'];
                $soitem['si_amount'] = $v['product_info']['p_discount'] * $v['num'];
                $soitem['si_p_tod'] = $v['product_info']['p_tod'];
                $soitem['si_vamount'] = 0;

                array_push($data['soitems'],$soitem);
            }

            $orderId = $this->chemsiteOrdersService->createOrders($data, $companyInfo['com_id']);
            if($orderId){
                $orderDetail = $this->chemsiteOrdersService->getCustomerOrderItemsByOrderId($customer['cus_id'],$orderId);
                //处理运费
                if($orderDetail){
                    $orderDetail['so_freight_price'] = 0;
                    foreach($orderDetail['items'] as $key => $item){
                        if($item['p_id'] == 0){
                            $orderDetail['so_freight_price'] = $item['si_amount'];
                            unset($orderDetail['items'][$key]);
                        }
                    }
                }
                $orderDetail = app(OrderDetailTransformer::class)->transform([$orderDetail]);
                return current($orderDetail);
            }
            return null;
        }catch(\Throwable $exception){
            SimpleLogs::writeLog($exception->getMessage(),__CLASS__.':createNewCustomerOrders','error');
            throw $exception;
        }
    }
}
